<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Wen_Biz
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @since 1.0.0
 *
 * @param array $classes Classes for the body element.
 * @return array (Maybe) filtered body classes.
 */
function wen_biz_body_classes( $classes ) {
	// Adds a class of custom-background-image to sites with a custom background image.
	if ( get_background_image() ) {
		$classes[] = 'custom-background-image';
	}

	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Always add a front-page class to the front page.
	if ( is_front_page() && ! is_home() ) {
		$classes[] = 'page-template-front-page';
	}

	// Adds a class of (full-width|box) to blogs.
	if ( 'boxed' === get_theme_mod( 'wen_biz_layout_type' ) ) {
		$classes[] = 'boxed-layout';
	} else {
		$classes[] = 'fluid-layout';
	}

	$navigation_class = get_theme_mod( 'wen_biz_menu_type', 'classic' );

	// Adds a class of navigation-(default|classic) to blogs.
	if ( 'modern' === $navigation_class ) {
		$classes[] = 'navigation-default';
	} elseif ( 'classic' === $navigation_class ) {
		$classes[] = 'navigation-classic';
	} elseif ( 'fullscreen' === $navigation_class ) {
		if ( wp_is_mobile() && 0 == get_theme_mod( 'wen_biz_mobile_fullscreen_enable' ) ) {
			$classes[] = 'navigation-default';
		} else {
			$classes[] = 'navigation-fullscreen';
		}
	}

	// Adds a class with respect to layout selected.
	$layout  = wen_biz_get_theme_layout();
	$sidebar = wen_biz_get_sidebar_id();

	$layout_class = "no-sidebar content-width-layout";

	if ( 'no-sidebar-full-width' === $layout ) {
		$layout_class = 'no-sidebar full-width-layout';
	} elseif ( 'left-sidebar' === $layout ) {
		if ( '' !== $sidebar ) {
			$layout_class = 'two-columns-layout content-right';
		}
	} elseif ( 'right-sidebar' === $layout ) {
		if ( '' !== $sidebar ) {
			$layout_class = 'two-columns-layout content-left';
		}
	}

	$classes[] = $layout_class;

	$classes[] = esc_attr( get_theme_mod( 'wen_biz_content_layout', 'excerpt' ) );

	$classes[] = 'header-media-fluid';

	$enable_sticky_playlist = get_theme_mod( 'wen_biz_sticky_playlist_visibility', 'disabled' );

	if ( wen_biz_check_section( $enable_sticky_playlist ) ) {
		$classes[] = 'sticky-playlist-enabled';
	}

	if( get_theme_mod('wen_biz_gradient_button', 1 ) ) {
		$classes[] = 'is-gradient-button';
	}

	$enable_slider = wen_biz_check_section( get_theme_mod( 'wen_biz_slider_option', 'disabled' ) );

	$header_image = wen_biz_featured_overall_image();

	if ( 'disable' !== $header_image ) {
		$classes[] = 'has-header-media';
	}

	if ( ! ( wen_biz_has_header_media_text() ) ) {
		$classes[] = 'header-media-text-disabled';
	}

	// Add a class if there is a custom header.
	if ( has_header_image() ) {
		$classes[] = 'has-header-image';
	}

	// Added color scheme to body class.
	$classes[] = 'color-scheme-' . esc_attr( get_theme_mod( 'color_scheme', 'default' ) );

	return $classes;
}
add_filter( 'body_class', 'wen_biz_body_classes' );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function wen_biz_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'wen_biz_pingback_header' );

if ( ! function_exists( 'wen_biz_comments' ) ) :
	/**
	 * Enable/Disable Comments
	 *
	 * @uses comment_form_default_fields filter
	 * @since 1.0.0
	 */
	function wen_biz_comments( $open, $post_id ) {
		$comment_select = get_theme_mod( 'wen_biz_comment_option', 'use-wordpress-setting' );

		if ( 'disable-completely' === $comment_select ) {
			return false;
		} elseif ( 'disable-in-pages' === $comment_select && is_page() ) {
			return false;
		}

		return $open;
	}
endif; // wen_biz_comments.
add_filter( 'comments_open', 'wen_biz_comments', 10, 2 );

if ( ! function_exists( 'wen_biz_comment_form_fields' ) ) :
	/**
	 * Modify Comment Form Fields
	 *
	 * @uses comment_form_default_fields filter
	 * @since 1.0.0
	 */
	function wen_biz_comment_form_fields( $fields ) {
		$commenter = wp_get_current_commenter();
		$req       = get_option( 'require_name_email' );
		$label     = $req ? ' *' : ' ' . esc_html__( '(optional)', 'wen-biz-pro' );
		$aria_req  = $req ? "aria-required='true'" : '';

		$fields['author'] =
			'<p class="comment-form-author">
				<input id="author" name="author" type="text" placeholder="' . esc_attr__( "Name", "wen-biz-pro" ) . $label . '" value="' . esc_attr( $commenter['comment_author'] ) .
			'" size="30" ' . $aria_req . ' />
			</p>';

		$fields['email'] =
			'<p class="comment-form-email">
				<input id="email" name="email" type="email" placeholder="' . esc_attr__( "Email", "wen-biz-pro" ) . $label . '" value="' . esc_attr( $commenter['comment_author_email'] ) .
			'" size="30" ' . $aria_req . ' />
			</p>';

		$disable_website = get_theme_mod( 'wen_biz_website_field', 1  );

		if ( isset( $fields['url'] ) && ! $disable_website ) {
			unset( $fields['url'] );
		} else {
			$fields['url'] =
			'<p class="comment-form-url">
				<input id="url" name="url" type="url"  placeholder="' . esc_attr__( "Website", "wen-biz-pro" ) . '" value="' . esc_attr( $commenter['comment_author_url'] ) .
			'" size="30" />
				</p>';
		}

		return $fields;
	}
endif; // wen_biz_comment_form_fields.
add_filter( 'comment_form_default_fields', 'wen_biz_comment_form_fields' );

if ( ! function_exists( 'wen_biz_comment_field' ) ) :
	/**
	 * Modify Comment Textarea Fields
	 *
	 * @uses comment_form_field_comment filter
	 * @since 1.0.0
	 */
	function wen_biz_comment_field( $comment_field ) {
	  $comment_field =
	    '<p class="comment-form-comment">
	            <textarea required id="comment" name="comment" placeholder="' . esc_attr__( "Comment", "wen-biz-pro" ) . ' *' . '" cols="45" rows="8" aria-required="true"></textarea>
	        </p>';

	  return $comment_field;
	}
endif; // wen_biz_comment_field.
add_filter( 'comment_form_field_comment', 'wen_biz_comment_field' );

/**
 * Adds font family custom CSS
 */
function wen_biz_get_font_family_css() {
	$font_family_options = wen_biz_font_family_options();

	$fonts = wen_biz_avaliable_fonts();

	$css = array();

	foreach ( $font_family_options as $key => $value ) {
		$option = get_theme_mod( $key, $value['default'] );

		if ( $option !== $value['default'] ) {
			$css[] = $value['selector'] . ' { font-family: ' . $fonts [ $option ]['label'] . '; }';
		}
	}

	$css = implode( PHP_EOL, $css );

	wp_add_inline_style( 'wen-biz-style', $css );
}
add_action( 'wp_enqueue_scripts', 'wen_biz_get_font_family_css', 11 );

/**
 * Adds custom overlay for Promotion Headline Background Image
 */
function wen_biz_promo_head_bg_image_overlay_css() {
	$enable   = get_theme_mod( 'wen_biz_promo_head_visibility', 'disabled' );

	if ( ! wen_biz_check_section( $enable ) ) {
		// Bail if promo section is disabled.
		return;
	}

	$content_align = get_theme_mod( 'wen_biz_promo_head_image_position', 'content-align-center' );

	if ( 'content-align-center' !== $content_align ) {
		// Bail if content-align-center is not set.
		return;
	}

	$overlay = get_theme_mod( 'wen_biz_promo_head_background_image_opacity', 0 );

	if ( $overlay ) {
		$overlay_bg = $overlay / 100;

		$css = '.promotion-section .cover-link:before {
			background-color: rgba(0, 0, 0, ' . esc_attr( $overlay_bg ) . ' );
		} '; // Dividing by 100 as the option is shown as % for user

		wp_add_inline_style( 'wen-biz-style', $css );
	}

	
}
add_action( 'wp_enqueue_scripts', 'wen_biz_promo_head_bg_image_overlay_css', 11 );

/**
 * Adds custom overlay for Promotion Contact Background Image
 */
function wen_biz_promotional_video_bg_image_overlay_css() {
	$enable   = get_theme_mod( 'wen_biz_promotional_video_option', 'disabled' );

	if ( ! wen_biz_check_section( $enable ) ) {
		// Bail if promo section is disabled.
		return;
	}

	$bg_image = get_theme_mod( 'wen_biz_promotional_video_bg_image' );
	$overlay = get_theme_mod( 'wen_biz_promotional_video_background_image_opacity', 50 );

	if ( $bg_image ) {
		$overlay_bg = $overlay / 100;

		$css = '.promotional-video-section:before {
			background-color: rgba(0, 0, 0, ' . esc_attr( $overlay_bg ) . ' );
		} '; // Dividing by 100 as the option is shown as % for user

		wp_add_inline_style( 'wen-biz-style', $css );
	}
}
add_action( 'wp_enqueue_scripts', 'wen_biz_promotional_video_bg_image_overlay_css', 11 );

/**
 * Adds featured video background CSS
 */
function wen_biz_promotional_video_bg_css() {
	$enable   = get_theme_mod( 'wen_biz_promotional_video_option', 'disabled' );

	if ( ! wen_biz_check_section( $enable ) ) {
		// Bail if contact section is disabled.
		return;
	}

	$background = get_theme_mod( 'wen_biz_promotional_video_bg_image' );

	if ( $background ) {
		$css = '#promotional-video-section { background-image: url("' . esc_url( $background ) . '"); }';

		wp_add_inline_style( 'wen-biz-style', $css );
	}

	
}
add_action( 'wp_enqueue_scripts', 'wen_biz_promotional_video_bg_css', 11 );

/**
 * Adds custom overlay for Header Media
 */
function wen_biz_header_media_image_overlay_css() {
	$overlay = get_theme_mod( 'wen_biz_header_media_image_opacity', 70 );

	if ( $overlay ) {
		$overlay_bg = $overlay / 100;

		$css = '.custom-header-overlay {
			background-color: rgba(2, 2, 2, ' . esc_attr( $overlay_bg ) . ' );
		} '; // Dividing by 100 as the option is shown as % for user

		wp_add_inline_style( 'wen-biz-style', $css );
	}

	
}
add_action( 'wp_enqueue_scripts', 'wen_biz_header_media_image_overlay_css', 11 );

/**
 * Adds custom overlay for Slider
 */
function wen_biz_slider_image_overlay_css() {
	$enable_slider = wen_biz_check_section( get_theme_mod( 'wen_biz_slider_option', 'disabled' ) );

	if ( ! $enable_slider ) {
		return;
	}
	
	$overlay = get_theme_mod( 'wen_biz_slider_opacity', 33 );

	if ( $overlay ) {
		$overlay_bg = $overlay / 100;
	
		$css = '#feature-slider-section .post-thumbnail:before {
			background-color: rgba(0, 0, 0, ' . esc_attr( $overlay_bg ) . ' );
		} '; // Dividing by 100 as the option is shown as % for user

		wp_add_inline_style( 'wen-biz-style', $css );
	}
}
add_action( 'wp_enqueue_scripts', 'wen_biz_slider_image_overlay_css', 11 );

/**
 * Adds Slider image CSS
 */
function wen_biz_slider_image_position_css() {
	$css = '';

	$image_position_mobile = get_theme_mod( 'wen_biz_slider_image_position_mobile', 'center center' );

	if ( 'center center' !== $image_position_mobile ) {
		$css = '#feature-slider-section .post-thumbnail img {
			object-position: '. esc_attr( $image_position_mobile ) . ';
		} ';
	}

	$image_position_desktop = get_theme_mod( 'wen_biz_slider_image_position_desktop', 'center center' );

	if ( 'center center' !== $image_position_desktop ) {
		$css .= '
		@media only screen and (min-width: 64em) {
			#feature-slider-section .post-thumbnail img {
				object-position: '. esc_attr( $image_position_desktop ) . ';
			}
		}';
	}

	wp_add_inline_style( 'wen-biz-style', $css );
}
add_action( 'wp_enqueue_scripts', 'wen_biz_slider_image_position_css', 11 );

/**
 * Remove first post from blog as it is already show via recent post template
 */
function wen_biz_alter_home( $query ) {
	if ( $query->is_home() && $query->is_main_query() ) {
		$cats = get_theme_mod( 'wen_biz_front_page_category' );

		if ( is_array( $cats ) && ! in_array( '0', $cats ) ) {
			$query->query_vars['category__in'] = $cats;
		}

		if ( get_theme_mod( 'wen_biz_exclude_slider_post' ) ) {
			$quantity = get_theme_mod( 'wen_biz_slider_number', 4 );

			$post_list	= array();	// list of valid post ids

			for( $i = 1; $i <= $quantity; $i++ ){
				if ( get_theme_mod( 'wen_biz_slider_post_' . $i ) && get_theme_mod( 'wen_biz_slider_post_' . $i ) > 0 ) {
					$post_list = array_merge( $post_list, array( get_theme_mod( 'wen_biz_slider_post_' . $i ) ) );
				}
			}

			if ( ! empty( $post_list ) ) {
				$query->query_vars['post__not_in'] = $post_list;
			}
		}
	}
}
add_action( 'pre_get_posts', 'wen_biz_alter_home' );

/**
 * Function to add Scroll Up icon
 */
function wen_biz_scrollup() {
	$disable_scrollup =  ! get_theme_mod( 'wen_biz_disable_scrollup', 1 );

	if ( $disable_scrollup ) {
		return;
	}

	echo '<a href="#masthead" id="scrollup" class="backtotop">' .  wen_biz_get_svg( array( 'icon' => 'scrollup' ) ) . '<span class="screen-reader-text">' . esc_html__( 'Scroll Up', 'wen-biz-pro' ) . '</span></a>' ;

}
add_action( 'wp_footer', 'wen_biz_scrollup', 1 );

if ( ! function_exists( 'wen_biz_content_nav' ) ) :
	/**
	 * Display navigation/pagination when applicable
	 *
	 * @since 1.0.0
	 */
	function wen_biz_content_nav() {
		global $wp_query;

		// Don't print empty markup in archives if there's only one page.
		if ( $wp_query->max_num_pages < 2 && ( is_home() || is_archive() || is_search() ) ) {
			return;
		}

		$pagination_type = get_theme_mod( 'wen_biz_pagination_type', 'default' );

		if ( ( class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'infinite-scroll' ) ) || class_exists( 'Catch_Infinite_Scroll' ) ) {
			// Support infinite scroll plugins.
			the_posts_navigation();
		} elseif ( 'numeric' === $pagination_type && function_exists( 'the_posts_pagination' ) ) {
			the_posts_pagination( array(
				'prev_text'          => '<span>' . wen_biz_get_svg( array('icon' => 'angle-left') ) . '</span>',
				'next_text'          => '<span>' . wen_biz_get_svg( array('icon' => 'angle-right') ) . '</span>',
				'screen_reader_text' => '<span class="nav-subtitle screen-reader-text">' . esc_html__( 'Page', 'wen-biz-pro' ) . ' </span>',
			) );
		} else {
			the_posts_navigation();
		}
	}
endif; // wen_biz_content_nav

/**
 * Check if a section is enabled or not based on the $value parameter
 * @param  string $value Value of the section that is to be checked
 * @return boolean return true if section is enabled otherwise false
 */
function wen_biz_check_section( $value ) {
	return ( 'entire-site' == $value  || ( is_front_page() && 'homepage' === $value ) );
}

/**
 * Return the first image in a post. Works inside a loop.
 * @param [integer] $post_id [Post or page id]
 * @param [string/array] $size Image size. Either a string keyword (thumbnail, medium, large or full) or a 2-item array representing width and height in pixels, e.g. array(32,32).
 * @param [string/array] $attr Query string or array of attributes.
 * @return [string] image html
 *
 * @since 1.0.0
 */
function wen_biz_get_first_image( $postID, $size, $attr, $src = false ) {
	ob_start();

	ob_end_clean();

	$image 	= '';

	$output = preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', get_post_field('post_content', $postID ) , $matches);

	if ( isset( $matches[1][0] ) ) {
		// Get first image.
		$first_img = $matches[1][0];

		if ( $src ) {
			//Return url of src is true
			return $first_img;
		}

		return '<img class="wp-post-image" src="'. esc_url( $first_img ) .'">';
	}

	return false;
}

function wen_biz_get_theme_layout() {
	$layout = '';

	if ( is_page_template( 'templates/no-sidebar.php' ) ) {
		$layout = 'no-sidebar';
	} elseif ( is_page_template( 'templates/full-width-page.php' ) ) {
		$layout = 'no-sidebar-full-width';
	} elseif ( is_page_template( 'templates/left-sidebar.php' ) ) {
		$layout = 'left-sidebar';
	} elseif ( is_page_template( 'templates/right-sidebar.php' ) ) {
		$layout = 'right-sidebar';
	} else {
		$layout = get_theme_mod( 'wen_biz_default_layout', 'right-sidebar' );

		if ( is_home() || is_archive() ) {
			$layout = get_theme_mod( 'wen_biz_homepage_archive_layout', 'right-sidebar' );
		}

		if ( class_exists( 'WooCommerce' ) && ( is_shop() || is_woocommerce() || is_cart() || is_checkout() ) ) {
			$layout = get_theme_mod( 'wen_biz_woocommerce_layout', 'right-sidebar' );
		}
	}

	return $layout;
}

function wen_biz_get_sidebar_id() {
	$sidebar = $id = '';

	$layout = wen_biz_get_theme_layout();

	if ( 'no-sidebar-full-width' === $layout || 'no-sidebar' === $layout ) {
		return $sidebar;
	}

	// WooCommerce Shop Page excluding Cart and checkout.
	if ( class_exists( 'WooCommerce' ) && is_woocommerce() ) {
		$id = get_option( 'woocommerce_shop_page_id' );
	} else {
		// Blog Page or Front Page setting in Reading Settings.
		if ( 'page' == get_option('show_on_front') ) {
			$id = get_option('show_on_front');
		} elseif ( is_singular() ) {
			global $post;

			$id = $post->ID;

			if ( is_attachment() ) {
				$id = $post->post_parent;
			}
		}
	}

	$sidebaroptions = get_post_meta( $id, 'wen-biz-sidebar-option', true );

	if ( is_active_sidebar( 'sidebar-woo' ) && class_exists( 'WooCommerce' ) && ( is_woocommerce() || is_cart() || is_checkout() ) ) {
		$sidebar = 'sidebar-woo'; // WooCommerce Sidebar.
	} elseif ( is_active_sidebar( 'sidebar-optional-one' ) && 'optional-sidebar-one' === $sidebaroptions ) {
		$sidebar = 'sidebar-optional-one';
	} elseif ( is_active_sidebar( 'sidebar-optional-two' ) && 'optional-sidebar-two' === $sidebaroptions ) {
		$sidebar = 'sidebar-optional-two';
	} elseif ( is_active_sidebar( 'sidebar-optional-three' ) && 'optional-sidebar-three' === $sidebaroptions ) {
		$sidebar = 'sidebar-optional-three';
	} elseif ( is_active_sidebar( 'sidebar-optional-homepage' ) && ( is_front_page() || ( is_home() && get_the_ID() != $page_for_posts ) ) ) {
		$sidebar = 'sidebar-optional-homepage';
	} elseif ( is_active_sidebar( 'sidebar-optional-archive' ) && ( is_archive() || ( is_home() && get_the_ID() != $page_for_posts ) ) ) {
		$sidebar = 'sidebar-optional-archive';
	} elseif ( is_page() && is_active_sidebar( 'sidebar-optional-page' ) ) {
		$sidebar = 'sidebar-optional-page';
	} elseif ( is_single() && is_active_sidebar( 'sidebar-optional-post' ) ) {
		$sidebar = 'sidebar-optional-post';
	} elseif ( is_active_sidebar( 'sidebar-1' ) ) {
		$sidebar = 'sidebar-1'; // Primary Sidebar.
	}

	return $sidebar;
}

if ( ! function_exists( 'wen_biz_truncate_phrase' ) ) :
	/**
	 * Return a phrase shortened in length to a maximum number of characters.
	 *
	 * Result will be truncated at the last white space in the original string. In this function the word separator is a
	 * single space. Other white space characters (like newlines and tabs) are ignored.
	 *
	 * If the first `$max_characters` of the string does not contain a space character, an empty string will be returned.
	 *
	 * @since 1.0.0
	 *
	 * @param string $text            A string to be shortened.
	 * @param integer $max_characters The maximum number of characters to return.
	 *
	 * @return string Truncated string
	 */
	function wen_biz_truncate_phrase( $text, $max_characters ) {

		$text = trim( $text );

		if ( mb_strlen( $text ) > $max_characters ) {
			//* Truncate $text to $max_characters + 1
			$text = mb_substr( $text, 0, $max_characters + 1 );

			//* Truncate to the last space in the truncated string
			$text = trim( mb_substr( $text, 0, mb_strrpos( $text, ' ' ) ) );
		}

		return $text;
	}
endif; //wen_biz_truncate_phrase

if ( ! function_exists( 'wen_biz_get_the_content_limit' ) ) :
	/**
	 * Return content stripped down and limited content.
	 *
	 * Strips out tags and shortcodes, limits the output to `$max_char` characters, and appends an ellipsis and more link to the end.
	 *
	 * @since 1.0.0
	 *
	 * @param integer $max_characters The maximum number of characters to return.
	 * @param string  $more_link_text Optional. Text of the more link. Default is "(more...)".
	 * @param bool    $stripteaser    Optional. Strip teaser content before the more text. Default is false.
	 *
	 * @return string Limited content.
	 */
	function wen_biz_get_the_content_limit( $max_characters, $more_link_text = '(more...)', $stripteaser = false ) {

		$content = get_the_content( '', $stripteaser );

		// Strip tags and shortcodes so the content truncation count is done correctly.
		$content = strip_tags( strip_shortcodes( $content ), apply_filters( 'get_the_content_limit_allowedtags', '<script>,<style>' ) );

		// Remove inline styles / .
		$content = trim( preg_replace( '#<(s(cript|tyle)).*?</\1>#si', '', $content ) );

		// Truncate $content to $max_char
		$content = wen_biz_truncate_phrase( $content, $max_characters );

		// More link?
		if ( $more_link_text ) {
			$link   = apply_filters( 'get_the_content_more_link', sprintf( '<a href="%s" class="more-link">%s</a>', esc_url( get_permalink() ), $more_link_text ), $more_link_text );
			$output = sprintf( '<p>%s %s</p>', $content, $link );
		} else {
			$output = sprintf( '<p>%s</p>', $content );
			$link = '';
		}

		return apply_filters( 'wen_biz_get_the_content_limit', $output, $content, $link, $max_characters );

	}
endif; //wen_biz_get_the_content_limit

if ( ! function_exists( 'wen_biz_content_image' ) ) :
	/**
	 * Template for Featured Image in Archive Content
	 *
	 * To override this in a child theme
	 * simply fabulous-fluid your own wen_biz_content_image(), and that function will be used instead.
	 *
	 * @since 1.0.0
	 */
	function wen_biz_content_image() {
		if ( has_post_thumbnail() && wen_biz_jetpack_featured_image_display() && is_singular() ) {
			global $post, $wp_query;

			// Get Page ID outside Loop.
			$page_id = $wp_query->get_queried_object_id();

			if ( $post ) {
				if ( is_attachment() ) {
					$parent = $post->post_parent;

					$individual_featured_image = get_post_meta( $parent, 'wen-biz-featured-image', true );
				} else {
					$individual_featured_image = get_post_meta( $page_id, 'wen-biz-featured-image', true );
				}
			}

			if ( empty( $individual_featured_image ) ) {
				$individual_featured_image = 'default';
			}

			if ( 'disable' === $individual_featured_image ) {
				echo '<!-- Page/Post Single Image Disabled or No Image set in Post Thumbnail -->';
				return false;
			} else {
				$class = array();

				$image_size = 'post-thumbnail';

				if ( 'default' !== $individual_featured_image ) {
					$image_size = $individual_featured_image;
					$class[]    = 'from-metabox';
				} else {
					$layout = wen_biz_get_theme_layout();

					if ( 'no-sidebar-full-width' === $layout ) {
						$image_size = 'wen-biz-slider';
					}
				}

				$class[] = $individual_featured_image;
				?>
				<div class="post-thumbnail <?php echo esc_attr( implode( ' ', $class ) ); ?>">
					<a href="<?php the_permalink(); ?>">
					<?php the_post_thumbnail( $image_size ); ?>
					</a>
				</div>
			<?php
			}
		} // End if ().
	}
endif; // wen_biz_content_image.

if ( ! function_exists( 'wen_biz_enable_homepage_posts' ) ) :
	/**
	 * Determine Homepage Content disabled or not
	 * @return boolean
	 */
	function wen_biz_enable_homepage_posts() {
	   if ( ! ( ! get_theme_mod( 'wen_biz_display_homepage_posts', 1 ) && is_front_page() ) ) {
			return true;
		}
		return false;
	}
endif; // wen_biz_enable_homepage_posts.

if ( ! function_exists( 'wen_biz_sections' ) ) :
	/**
	 * Display Sections on header and footer with respect to the section option set in wen_biz_sections_sort
	 */
	function wen_biz_sections( $selector = 'header' ) {
		$sections = get_theme_mod( 'wen_biz_sections_sort', wen_biz_get_default_sections_value() );

		$separated_sections = explode( 'main-content,', $sections );

		$sections = $separated_sections[0];

		if ( 'footer' === $selector ) {
			$sections = $separated_sections[1];
		}

		$sections =  ! empty( $sections ) ? explode( ',', $sections ) : array();

		foreach ( $sections as $section ) {
			$all_sections = wen_biz_get_sortable_sections();

			if ( isset( $all_sections[ $section ]['template-part'] ) ) {
				get_template_part( $all_sections[ $section ]['template-part'] );
			}
		}
	}
endif;

if ( ! function_exists( 'wen_biz_get_sortable_sections' ) ) :
	/**
	 * Returns list of sortable sections
	 */
	function wen_biz_get_sortable_sections() {
		$sortable_sections = array(
			'header-media'          => array(
				'label'         => esc_html__( 'Header Media', 'wen-biz-pro' ),
				'section'       => 'header_image',
				'template-part' => 'template-parts/header/header-media',
			),
			'slider'                => array(
				'label'         => esc_html__( 'Slider', 'wen-biz-pro' ),
				'section'       => 'wen_biz_featured_slider',
				'template-part' => 'template-parts/slider/display-slider',
			),
			'portfolio'             => array(
				'label'         => esc_html__( 'Portfolio', 'wen-biz-pro' ),
				'section'       => 'wen_biz_portfolio',
				'template-part' => 'template-parts/portfolio/display-portfolio',
			),
			'logo-slider'           => array(
				'label'         => esc_html__( 'Logo Slider', 'wen-biz-pro' ),
				'section'       => 'wen_biz_logo_slider',
				'template-part' => 'template-parts/logo-slider/display-logo-slider',
			),
			'hero-content'          => array(
				'label'         => esc_html__( 'Hero Content', 'wen-biz-pro' ),
				'section'       => 'wen_biz_hero_content_options',
				'template-part' => 'template-parts/hero-content/content-hero',
			),
			'testimonial'           => array(
				'label'         => esc_html__( 'Testimonial', 'wen-biz-pro' ),
				'section'       => 'wen_biz_testimonials',
				'template-part' => 'template-parts/testimonial/display-testimonial',
			),
			'promotion-headline'    => array(
				'label'         => esc_html__( 'Promotion headline', 'wen-biz-pro' ),
				'section'       => 'wen_biz_promotion_headline',
				'template-part' => 'template-parts/promotion-headline/content-promotion',
			),
			'featured-content'      => array(
				'label'         => esc_html__( 'Featured Content', 'wen-biz-pro' ),
				'section'       => 'wen_biz_featured_content',
				'template-part' => 'template-parts/featured-content/display-featured',
			),
			'service'              => array(
				'label'         => esc_html__( 'Services', 'wen-biz-pro' ),
				'section'       => 'wen_biz_service',
				'template-part' => 'template-parts/service/display-service',
			),
			'promotional-video'          => array(
				'label'         => esc_html__( 'Promotional Video', 'wen-biz-pro' ),
				'section'       => 'wen_biz_promotional_video_options',
				'template-part' => 'template-parts/promotional-video/display-video',
			),
			'team'          => array(
				'label'         => esc_html__( 'Team', 'wen-biz-pro' ),
				'section'       => 'wen_biz_team',
				'template-part' => 'template-parts/team/display-team',
			),
			'promotion-content'          => array(
				'label'         => esc_html__( 'Promotion Content', 'wen-biz-pro' ),
				'section'       => 'wen_biz_promotion_content_options',
				'template-part' => 'template-parts/promotion-content/content-promotion',
			),
			'pricing'          => array(
				'label'         => esc_html__( 'Pricing', 'wen-biz-pro' ),
				'section'       => 'wen_biz_pricing',
				'template-part' => 'template-parts/pricing/display-pricing',
			),
			'categories'               => array(
				'label'         => esc_html__( 'Categories', 'wen-biz-pro' ),
				'section'       => 'wen_biz_timeline',
				'template-part' => 'template-parts/categories/display-categories',
			),
			'gallery'               => array(
				'label'         => esc_html__( 'Gallery', 'wen-biz-pro' ),
				'section'       => 'wen_biz_gallery_options',
				'template-part' => 'template-parts/gallery/content-gallery',
			),
			'woo-products-showcase' => array(
				'label'         => esc_html__( 'Woo Products Showcase', 'wen-biz-pro' ),
				'section'       => 'wen_biz_woo_products_showcase',
				'template-part' => 'template-parts/woo-products-showcase/display-products',
			),
			'stats'                 => array(
				'label'         => esc_html__( 'Stats', 'wen-biz-pro' ),
				'section'       => 'wen_biz_stats',
				'template-part' => 'template-parts/stats/display-stats',
			),
			'main-content'          => array(
				'label' => esc_html__( 'Main Content', 'wen-biz-pro' ),
			),
			'recent-posts'          => array(
				'label'         => esc_html__( 'Recent Posts ( Only on homepage )', 'wen-biz-pro' ),
				'section'       => 'wen_biz_homepage_options',
				'template-part' => 'template-parts/recent-posts/front-recent-posts',
			),
			'newsletter'            => array(
				'label'         => esc_html__( 'Newsletter', 'wen-biz-pro' ),
				'section'       => 'sidebar-widgets-sidebar-newsletter',
				'template-part' => 'template-parts/footer/footer-newsletter',
			),
			'contact-form'           => array(
				'label'         => esc_html__( 'Contact Form', 'wen-biz-pro' ),
				'section'       => 'wen_biz_contact',
				'template-part' => 'template-parts/contact-form/display-contact',
			),
			'instagram'             => array(
				'label'         => esc_html__( 'Instagram', 'wen-biz-pro' ),
				'section'       => 'sidebar-widgets-sidebar-instagram',
				'template-part' => 'template-parts/footer/footer-instagram',
			),
		);

		return $sortable_sections;
	}
endif;

if ( ! function_exists( 'wen_biz_post_thumbnail' ) ) :
	/**
	 * $image_size post thumbnail size
	 * $type html, html-with-bg, url
	 * $echo echo true/false
	 * $no_thumb display no-thumb image or not
	 */
	function wen_biz_post_thumbnail( $image_size = 'post-thumbnail', $type = 'html', $echo = true, $no_thumb = false ) {
		$image = $image_url = '';

		if ( has_post_thumbnail() ) {
			$image_url = get_the_post_thumbnail_url( get_the_ID(), $image_size );
			$image     = get_the_post_thumbnail( get_the_ID(), $image_size );
		} else {
			if ( is_array( $image_size ) && $no_thumb ) {
				$image_url  = trailingslashit( get_template_directory_uri() ) . 'images/no-thumb-' . $image_size[0] . 'x' . $image_size[1] . '.jpg';
				$image      = '<img src="' . esc_url( $image_url ) . '" alt="" />';
			} elseif ( $no_thumb ) {
				global $_wp_additional_image_sizes;

				$image_url  = trailingslashit( get_template_directory_uri() ) . 'images/no-thumb-1920x822.jpg';

				if ( array_key_exists( $image_size, $_wp_additional_image_sizes ) ) {
					$image_url  = trailingslashit( get_template_directory_uri() ) . 'images/no-thumb-' . $_wp_additional_image_sizes[ $image_size ]['width'] . 'x' . $_wp_additional_image_sizes[ $image_size ]['height'] . '.jpg';
				}

				$image      = '<img src="' . esc_url( $image_url ) . '" alt="" />';
			}

			// Get the first image in page, returns false if there is no image.
			$first_image_url = wen_biz_get_first_image( get_the_ID(), $image_size, '', true );

			// Set value of image as first image if there is an image present in the page.
			if ( $first_image_url ) {
				$image_url = $first_image_url;
				$image = '<img class="wp-post-image" src="'. esc_url( $image_url ) .'">';
			}
		}

		if ( ! $image_url ) {
			// Bail if there is no image url at this stage.
			return;
		}

		if ( 'url' === $type ) {
			return $image_url;
		}

		$output = '<div';

		if ( 'html-with-bg' === $type ) {
			$output .= ' class="post-thumbnail-background" style="background-image: url( ' . esc_url( $image_url ) . ' )"';
		} else {
			$output .= ' class="post-thumbnail"';
		}

		$output .= '>';

		$output .= '<a class="cover-link" href="' . esc_url( get_the_permalink() ) . '" title="' . the_title_attribute( 'echo=0' ) . '">';

		if ( 'html-with-bg' !== $type ) {
			$output .= $image;
		}

		$output .= '</a></div><!-- .post-thumbnail -->';

		if ( ! $echo ) {
			return $output;
		}

		echo $output;
	}
endif;

if ( ! function_exists( 'wen_biz_testimonial_posts_args' ) ) :
	function wen_biz_testimonial_posts_args() {
		$number = get_theme_mod( 'wen_biz_testimonial_number', 5 );

		$args = array(
			'ignore_sticky_posts' => 1 // ignore sticky posts
		);

		$type = get_theme_mod( 'wen_biz_testimonial_type', 'category' );

		$post_list  = array();// list of valid post/page ids


		if ( 'post' === $type || 'jetpack-testimonial' === $type || 'page' === $type  ) {
			$args['post_type'] = $type;

			for ( $i = 1; $i <= $number; $i++ ) {
				$post_id = '';

				if ( 'post' === $type ) {
					$post_id = get_theme_mod( 'wen_biz_testimonial_post_' . $i );
				} elseif ( 'page' === $type ) {
					$post_id = get_theme_mod( 'wen_biz_testimonial_page_' . $i );
				} elseif ( 'jetpack-testimonial' === $type ) {
					$post_id =  get_theme_mod( 'wen_biz_testimonial_cpt_' . $i );
				}

				if ( $post_id && '' !== $post_id ) {
					// Polylang Support.
					if ( class_exists( 'Polylang' ) ) {
						$post_id = pll_get_post( $post_id, pll_current_language() );
					}

					$post_list = array_merge( $post_list, array( $post_id ) );

				}
			}

			$args['post__in'] = $post_list;
			$args['orderby'] = 'post__in';
		} elseif ( 'category' === $type ) {
			$no_of_post = $number;

			if ( get_theme_mod( 'wen_biz_testimonial_select_category' ) ) {
				$args['category__in'] = (array) get_theme_mod( 'wen_biz_testimonial_select_category' );
			}

			$args['post_type'] = 'post';
		} elseif ( 'tag' === $type ) {
			$no_of_post = $number;

			if ( get_theme_mod( 'wen_biz_testimonial_select_tag' ) ) {
				$args['tag__in'] = (array) get_theme_mod( 'wen_biz_testimonial_select_tag' );
			}

			$args['post_type'] = 'post';
		}

		$args['posts_per_page'] = $number;

		return $args;
	}
endif;

function wen_biz_get_posts_columns() {
	$columns = get_theme_mod( 'wen_biz_blog_post_layout', 'layout-one' );

	if ( is_front_page() ) {
		$columns = get_theme_mod( 'wen_biz_homepage_post_layout', 'layout-one' );
	}

	return $columns;
}

if ( ! function_exists( 'wen_biz_get_pricing_posts' ) ) :
	/**
	 * Pricing content posts
	 */
	function wen_biz_get_pricing_posts() {
		$type = get_theme_mod( 'wen_biz_pricing_type', 'category' );

		$number = get_theme_mod( 'wen_biz_pricing_number', 3 );

		$post_list    = array();

		$args = array(
			'posts_per_page'      => $number,
			'post_type'           => 'post',
			'ignore_sticky_posts' => 1, // ignore sticky posts.
		);

		// Get valid number of posts.
		if ( 'post' === $type || 'page' === $type ) {
			$args['post_type'] = $type;

			for ( $i = 1; $i <= $number; $i++ ) {
				$post_id = '';

				if ( 'post' === $type ) {
					$post_id = get_theme_mod( 'wen_biz_pricing_post_' . $i );
				} elseif ( 'page' === $type ) {
					$post_id = get_theme_mod( 'wen_biz_pricing_page_' . $i );
				} elseif ( 'ect-service' === $type ) {
					$post_id = get_theme_mod( 'wen_biz_pricing_cpt_' . $i );
				}

				if ( $post_id && '' !== $post_id ) {
					$post_list = array_merge( $post_list, array( $post_id ) );
				}
			}

			$args['post__in'] = $post_list;
			$args['orderby']  = 'post__in';
		} elseif ( 'category' === $type && $cat = get_theme_mod( 'wen_biz_pricing_select_category' ) ) {
			$args['category__in'] = $cat;
		}

		$pricing_posts = get_posts( $args );

		return $pricing_posts;
	}
endif;


if ( ! function_exists( 'wen_biz_primary_menu_active_buttons' ) ) :

	/**
	 * Pricing content posts
	 */
	function wen_biz_primary_menu_active_buttons() {
		$join_label   = get_theme_mod( 'wen_biz_primary_button_label', esc_html__( 'Free Consultation', 'wen-biz-pro' ) );
		$join_link    = get_theme_mod( 'wen_biz_primary_button_link' );
		$join_target  = get_theme_mod( 'wen_biz_primary_button_target' ) ? '_blank': '_self';
		if( $join_label ) : ?>
			<div class ="action-buttons">
				<?php if( $join_label ) : ?>
					<a class="button" target="<?php echo $join_target; ?>" href="<?php echo esc_url( $join_link ); ?>"><?php echo esc_html( $join_label ); ?></a>
				<?php endif; ?>
			</div>
		<?php endif; 
	}
endif;

/**
 * Customize video play/pause button in the custom header.
 */
function wen_biz_video_controls( $settings ) {
	$settings['l10n']['play'] = '<span class="screen-reader-text">' . esc_html__( 'Play background video', 'wen-biz-pro' ) . '</span>' . wen_biz_get_svg( array( 'icon' => 'play' ) );
	$settings['l10n']['pause'] = '<span class="screen-reader-text">' . esc_html__( 'Pause background video', 'wen-biz-pro' ) . '</span>' . wen_biz_get_svg( array( 'icon' => 'pause' ) );
	return $settings;
}
add_filter( 'header_video_settings', 'wen_biz_video_controls' );

if ( ! function_exists( 'wen_biz_team_social' ) ) :
	/**
	 * Returns list of social icons for team
	 */
	function wen_biz_team_social( $link ) {
		// Get supported social icons.
		$social_icons = wen_biz_social_links_icons();

		foreach ( $social_icons as $attr => $value ) {
			if ( false !== strpos( $link, $attr ) ) {
				return wen_biz_get_svg( array( 'icon' => esc_attr( $value ) ) );
			}
		}
	}
endif;

if ( ! function_exists( 'wen_biz_team_social_links' ) ) :
	/**
	 * Displays team social links html
	 */
	function wen_biz_team_social_links( $counter ) {
		$icons = array();
		for ( $j = 1; $j < 5; $j++ ) {
			if ( $link = get_theme_mod( 'wen_biz_team_social_link_' . $j . '_' . $counter ) ) {
				$icons[] = $link;
			}
		}

		if ( empty( $icons ) ) {
			// Bail if any social icon is not set.
			return;
		}
		?>
		<div class="artist-social-profile">
			<nav class="social-navigation" role="navigation" aria-label="Social Menu">
				<div class="menu-social-container">
					<ul id="menu-social-menu" class="social-links-menu">
						<?php foreach( $icons as $icon ) : ?>
							<li class="menu-item">
								<a target="_blank" rel="nofollow" href="<?php echo esc_url( $icon ); ?>">
									<?php 
									echo wen_biz_team_social( $icon ); // WPCS: XSS ok. ?>
								</a>
							</li>
						<?php endforeach; ?>
					</ul>
				</div>
			</nav>
		</div><!-- .artist-social-profile -->
		<?php
	}
endif;